@@ -26,6 +26,7 @@
 #include <qpointer.h>
 #include <qsettings.h>
 #include <qurl.h>
+#include <QClipboard>
 
 #include "qaccessibilityclient/registry.h"
 #include "qaccessibilityclient/registrycache_p.h"
@@ -153,17 +154,40 @@ void MainWindow::MainWindow::initActions()
     m_quitAction = new QAction(tr("&Quit"), this);
     m_quitAction->setShortcuts(QKeySequence::Quit);
     connect(m_quitAction, SIGNAL(triggered()), this, SLOT(close()));
+
+    m_copyValueAction = new QAction(tr("&Copy property value"), this);
+    m_copyValueAction->setShortcuts(QKeySequence::Copy);
+    connect(m_copyValueAction, SIGNAL(triggered()), this, SLOT(copyValue()));
+}
+
+void MainWindow::copyValue()
+{
+    QModelIndex selected = m_propertyView->currentIndex();
+
+    if (!selected.isValid())
+        return;
+
+    if (selected.column() == 0) {
+        selected = m_propertyView->model()->index(selected.row(), 1, selected.parent());
+        if (!selected.isValid())
+            return;
+    }
+
+    QGuiApplication::clipboard()->setText(selected.data(Qt::DisplayRole).toString());
 }
 
 void MainWindow::MainWindow::initMenu()
 {
-    QMenu *fileMenu = menuBar()->addMenu(QString("Tree"));
+    QMenu *fileMenu = menuBar()->addMenu(QString("&Tree"));
     fileMenu->addAction(m_resetTreeAction);
     fileMenu->addAction(m_followFocusAction);
     fileMenu->addSeparator();
     fileMenu->addAction(m_quitAction);
 
-    QMenu *settingsMenu = menuBar()->addMenu(QString("Settings"));
+    QMenu *editMenu = menuBar()->addMenu(QString("&Edit"));
+    editMenu->addAction(m_copyValueAction);
+
+    QMenu *settingsMenu = menuBar()->addMenu(QString("&Settings"));
     QMenu *dockerMenu = settingsMenu->addMenu(QString("Docker"));
     Q_FOREACH(const QDockWidget *docker, findChildren<QDockWidget*>()) {
         dockerMenu->addAction(docker->toggleViewAction());
@@ -198,7 +222,7 @@ void MainWindow::MainWindow::initUi()
     connect(m_accessibleObjectTreeView->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)), this, SLOT(selectionChanged(QModelIndex,QModelIndex)));
     connect(m_accessibleObjectTreeView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(treeCustomContextMenuRequested(QPoint)));
 
-    QDockWidget *propertyDocker = new QDockWidget(QString("Properties"), this);
+    QDockWidget *propertyDocker = new QDockWidget(QString("&Properties"), this);
     propertyDocker->setObjectName("properties");
     propertyDocker->setFeatures(QDockWidget::AllDockWidgetFeatures);
     m_propertyView = new QTreeView(propertyDocker);
@@ -208,13 +232,13 @@ void MainWindow::MainWindow::initUi()
     m_propertyView->setRootIsDecorated(false);
     m_propertyView->setItemsExpandable(true);
     m_propertyView->setExpandsOnDoubleClick(false);
-    m_propertyView->setEditTriggers(QAbstractItemView::NoEditTriggers);
+    m_propertyView->setEditTriggers(QAbstractItemView::DoubleClicked | QAbstractItemView::AnyKeyPressed | QAbstractItemView::EditKeyPressed);
     m_propertyModel = new ObjectProperties(this);
     m_propertyView->setModel(m_propertyModel);
     m_propertyView->setAlternatingRowColors(true);
     connect(m_propertyView, SIGNAL(doubleClicked(QModelIndex)), m_propertyModel, SLOT(doubleClicked(QModelIndex)));
 
-    QDockWidget *uiDocker = new QDockWidget(QString("Boundaries"), this);
+    QDockWidget *uiDocker = new QDockWidget(QString("&Boundaries"), this);
     uiDocker->setObjectName("boundaries");
     uiDocker->setFeatures(QDockWidget::AllDockWidgetFeatures);
     m_uiview = new UiView(uiDocker);
@@ -222,7 +246,7 @@ void MainWindow::MainWindow::initUi()
     m_uiview->setAccessibleDescription(QString("Visualize the component boundaries"));
     uiDocker->setWidget(m_uiview);
 
-    QDockWidget *eventsDocker = new QDockWidget(QString("Events"), this);
+    QDockWidget *eventsDocker = new QDockWidget(QString("E&vents"), this);
     eventsDocker->setObjectName("events");
     eventsDocker->setFeatures(QDockWidget::AllDockWidgetFeatures);
     m_eventsWidget = new EventsWidget(m_registry, eventsDocker);
