@@ -27,6 +27,7 @@
 #include <qdbuspendingcall.h>
 #include <qdbusinterface.h>
 #include <qdbusargument.h>
+#include <qdbusmetatype.h>
 
 #include <qdebug.h>
 #include <qdbusmessage.h>
@@ -40,10 +41,6 @@
 #include <qstring.h>
 #include <qhash.h>
 
-#ifdef QT4_BUILD
-#define QStringLiteral(x) QLatin1String(x)
-#endif
-
 // interface names from at-spi2-core/atspi/atspi-misc-private.h
 #define ATSPI_DBUS_NAME_REGISTRY "org.a11y.atspi.Registry"
 #define ATSPI_DBUS_PATH_REGISTRY "/org/a11y/atspi/registry"
@@ -95,8 +92,10 @@ QString RegistryPrivate::ACCESSIBLE_OBJECT_SCHEME_STRING = QLatin1String("access
 RegistryPrivate::RegistryPrivate(Registry *qq)
     :q(qq)
     , m_subscriptions(Registry::NoEventListeners)
-    , m_cache(new CacheWeakStrategy())
+    , m_cache(nullptr)
 {
+    qDBusRegisterMetaType<QVector<quint32> >();
+
     connect(&conn, SIGNAL(connectionFetched()), this, SLOT(connectionFetched()));
     connect(&m_actionMapper, SIGNAL(mapped(QString)), this, SLOT(actionTriggered(QString)));
     init();
@@ -111,7 +110,7 @@ void RegistryPrivate::init()
     interfaceHash[QLatin1String(ATSPI_DBUS_INTERFACE_COLLECTION)] = AccessibleObject::CollectionInterface;
     interfaceHash[QLatin1String(ATSPI_DBUS_INTERFACE_COMPONENT)] = AccessibleObject::ComponentInterface;
     interfaceHash[QLatin1String(ATSPI_DBUS_INTERFACE_DOCUMENT)] = AccessibleObject::DocumentInterface;
-    interfaceHash[QLatin1String(ATSPI_DBUS_INTERFACE_EDITABLE_TEXT)] = AccessibleObject::TextInterface;
+    interfaceHash[QLatin1String(ATSPI_DBUS_INTERFACE_EDITABLE_TEXT)] = AccessibleObject::EditableTextInterface;
     interfaceHash[QLatin1String(ATSPI_DBUS_INTERFACE_EVENT_KEYBOARD)] = AccessibleObject::EventKeyboardInterface;
     interfaceHash[QLatin1String(ATSPI_DBUS_INTERFACE_EVENT_MOUSE)] = AccessibleObject::EventMouseInterface;
     interfaceHash[QLatin1String(ATSPI_DBUS_INTERFACE_EVENT_OBJECT)] = AccessibleObject::EventObjectInterface;
@@ -198,7 +197,7 @@ void RegistryPrivate::connectionFetched()
 
     if (m_pendingSubscriptions > 0) {
         subscribeEventListeners(m_pendingSubscriptions);
-        m_pendingSubscriptions = 0;
+        m_pendingSubscriptions = nullptr;
     }
 }
 
@@ -595,7 +594,7 @@ AccessibleObject::Role RegistryPrivate::role(const AccessibleObject &object) con
         qWarning() << "Could not access role." << reply.error().message();
         return AccessibleObject::NoRole;
     }
-    return atspiRoleToRole((AtspiRole)reply.value());
+    return atspiRoleToRole(static_cast<AtspiRole>(reply.value()));
 }
 
 AccessibleObject::Role RegistryPrivate::atspiRoleToRole(AtspiRole role)
@@ -737,17 +736,32 @@ QString RegistryPrivate::localizedRoleName(const AccessibleObject &object) const
 
 quint64 RegistryPrivate::state(const AccessibleObject &object) const
 {
+    if (m_cache) {
+        quint64 cachedValue = m_cache->state(object);
+        if (cachedValue != QAccessibleClient::ObjectCache::StateNotFound)
+            return cachedValue;
+    }
+
     QDBusMessage message = QDBusMessage::createMethodCall (
                 object.d->service, object.d->path, QLatin1String("org.a11y.atspi.Accessible"), QLatin1String("GetState"));
 
-    QDBusReply<QList<quint32> > reply = conn.connection().call(message);
+    QDBusReply<QVector<quint32> > reply = conn.connection().call(message);
     if (!reply.isValid()) {
         qWarning() << "Could not access state." << reply.error().message();
         return 0;
     }
-    int low = reply.value().at(0);
-    int high = reply.value().at(1);
-    quint64 state = low + ((quint64)high << 32);
+    if (reply.value().size() < 2) {
+        qWarning() << "Did not receive expected reply.";
+        return 0;
+    }
+    quint32 low = reply.value().at(0);
+    quint32 high = reply.value().at(1);
+    quint64 state = low + (static_cast<quint64>(high) << 32);
+
+    if (m_cache) {
+        m_cache->setState(object, state);
+    }
+
     return state;
 }
 
@@ -858,7 +872,9 @@ AccessibleObject::Interfaces RegistryPrivate::supportedInterfaces(const Accessib
         interfaces |= interfaceHash[interface];
     }
 
-    m_cache->setInterfaces(object, interfaces);
+    if (m_cache) {
+        m_cache->setInterfaces(object, interfaces);
+    }
 
     return interfaces;
 }
@@ -965,7 +981,7 @@ QString RegistryPrivate::text(const AccessibleObject &object, int startOffset, i
 QString RegistryPrivate::textWithBoundary(const AccessibleObject &object, int offset, AccessibleObject::TextBoundary boundary, int *startOffset, int *endOffset) const
 {
     QDBusMessage message = QDBusMessage::createMethodCall(object.d->service, object.d->path, QLatin1String("org.a11y.atspi.Text"), QLatin1String("GetTextAtOffset"));
-    message.setArguments(QVariantList() << offset << (AtspiTextBoundaryType) boundary);
+    message.setArguments(QVariantList() << offset << static_cast<AtspiTextBoundaryType>(boundary));
     QDBusMessage reply = conn.connection().call(message);
     if (reply.type() != QDBusMessage::ReplyMessage || reply.signature() != QStringLiteral("sii")) {
         qWarning() << "Could not access text." << reply.errorMessage();
@@ -1093,7 +1109,7 @@ QString RegistryPrivate::appLocale(const AccessibleObject &object, uint lctype)
     args.append(lctype);
     message.setArguments(args);
 
-    QDBusReply<QString> reply = conn.connection().call(message);
+    QDBusReply<QString> reply = conn.connection().call(message, QDBus::Block, 500);
     if (!reply.isValid()) {
         qWarning() << "Could not access appLocale." << reply.error().message();
         return QString();
@@ -1136,6 +1152,23 @@ double RegistryPrivate::currentValue(const AccessibleObject &object) const
     return v.toDouble();
 }
 
+bool RegistryPrivate::setCurrentValue(const AccessibleObject &object, double value)
+{
+    QDBusMessage message = QDBusMessage::createMethodCall(object.d->service, object.d->path, QLatin1String("org.a11y.atspi.Value"), QLatin1String("SetCurrentValue"));
+
+    QVariantList arguments;
+    arguments << QLatin1String("org.a11y.atspi.Value") <<  QLatin1String("CurrentValue");
+    arguments << QVariant::fromValue(QDBusVariant(value));
+    message.setArguments(arguments);
+
+    QDBusReply<bool> reply = conn.connection().call(message);
+    if (!reply.isValid()) {
+        qWarning() << "Could not set text." << reply.error().message();
+        return false;
+    }
+    return reply.value();
+}
+
 QList<AccessibleObject> RegistryPrivate::selection(const AccessibleObject &object) const
 {
     QList<AccessibleObject> result;
@@ -1205,7 +1238,7 @@ QVector< QSharedPointer<QAction> > RegistryPrivate::actions(const AccessibleObje
     QVector< QSharedPointer<QAction> > list;
     for(int i = 0; i < actionArray.count(); ++i) {
         const QSpiAction &a = actionArray[i];
-        QAction *action = new QAction(0);
+        QAction *action = new QAction();
         QString id = QString(QLatin1String("%1;%2;%3")).arg(object.d->service).arg(object.d->path).arg(i);
         action->setObjectName(id);
         action->setText(a.name);
@@ -1389,14 +1422,17 @@ void RegistryPrivate::slotStateChanged(const QString &state, int detail1, int de
         return;
     }
 
+    AccessibleObject accessible = accessibleFromContext();
+    if (m_cache) {
+        m_cache->cleanState(accessible);
+    }
+
     if (state == QLatin1String("focused") && (detail1 == 1) &&
             (q->subscribedEventListeners().testFlag(Registry::Focus))) {
-        QAccessibleClient::AccessibleObject accessible = accessibleFromContext();
         emit q->focusChanged(accessible);
     }
 
     if (q->subscribedEventListeners().testFlag(Registry::StateChanged)) {
-        AccessibleObject accessible = accessibleFromContext();
         emit q->stateChanged(accessible, state, detail1 == 1);
     }
 }
@@ -1490,4 +1526,4 @@ void RegistryPrivate::slotTextChanged(const QString &change, int start, int end,
     }
 }
 
-#include "registry_p.moc"
+#include "moc_registry_p.cpp"
